function ruiFooterScreenController($scope, $element, eventAggregator, ScreenService) {
	/*
	 * -> footerHeight
	 * Sets the footerHeight in pixels
	 *
	 * -> footerProperties
	 * Contains the footerProperties object from the containers.json file
	 *
	 * -> footerDOM
	 * The DOM Object representing container of this controller
	 *
	 * -> currentWindow
	 * Informs the current opened window's name (in lowercase in order to be valid as window.openWindow() parameter)
	 *
	 * -> currentScrollTop
	 * Informs the current scrollTop property of the current container's DOM element
	 *
	 * -> isHidden
	 * Informs wether the container is currently hidden or not
	 *
	 * -> this.functionsToCallOnContainerOpen
	 * An array that contains the reference for all the functions that should be called by the OnContainerOpen event
	 */
	var footerHeight, footerProperties, footerDOM, currentWindow, currentScrollTop, isHidden;
	this.functionsToCallOnContainerOpen = [];

	/*
	 * Initializes variables and call functions needed for initializing the template
	 * Works like a class constructor
	 *
	 * return void
	 */
	this.initializeFooter = function() {
		footerHeight = 56;
		footerProperties = $scope.templateManager.containers.zeedhi_project.footerProperties;
		footerDOM = $element.get()[0];
		currentScrollTop = 0;
		isHidden = false;

		// var containerElement = document.getElementsByClassName('container')[0];
		// containerElement.classList.add('rui-has-footer');

		if (footerProperties.color == "flat")
			footerDOM.classList.add("rui-footer-flat");

		if (footerProperties.hideOnScrollDown) {
			this.addScrollEventToWindow();
			this.functionsToCallOnContainerOpen.push(this.addScrollEventToWindow.bind(this));
		}

		this.functionsToCallOnContainerOpen.push(this.selectFooterElement.bind(this));

		this.createDOMElementForEachFooterElement();
		this.selectFooterElement();
	};

	/*
	 * Iterates over footerProperties.elements for creating DOM element for each footerElement
	 * This function substiutes the ng-repeat AngularJS directive
	 *
	 * return void
	 */
	this.createDOMElementForEachFooterElement = function() {
		var footerElementDOMTemplate, newFooterElementDOM;

		footerElementDOMTemplate = footerDOM.querySelector("#rui-footer-element");

		for (var i=0; i<footerProperties.elements.length; i++) {
			newFooterElementDOM = footerElementDOMTemplate.cloneNode(true);
			newFooterElementDOM.setAttribute("id", "rui-footer-element-"+footerProperties.elements[i].windowName.toLowerCase());
			newFooterElementDOM.windowName = footerProperties.elements[i].windowName;
			newFooterElementDOM.addEventListener("click", this.changeWindow.bind(this));
			newFooterElementDOM.getElementsByTagName("span")[0].getElementsByTagName("i")[0].innerHTML = footerProperties.elements[i].icon;
			newFooterElementDOM.getElementsByTagName("p")[0].innerHTML = ScreenService.i18n(footerProperties.elements[i].label);

			footerDOM.appendChild(newFooterElementDOM);
		}

		footerDOM.removeChild(footerElementDOMTemplate);
	};

	/*
	 * Applies the selected effect on footerElement with windowName equal to the container's name
	 *
	 * return void
	 */
	this.selectFooterElement = function() {
		var footerElementDOM;

		if (currentWindow) {
			footerElementDOM = footerDOM.querySelector("#rui-footer-element-"+currentWindow.toLowerCase());
			if (footerElementDOM)
				footerElementDOM.classList.remove("selected");
		}

		currentWindow = $scope.templateManager.container.name;
		var newSelectedFooterElement = footerDOM.querySelector("#rui-footer-element-"+currentWindow.toLowerCase());
		if (newSelectedFooterElement) {
			newSelectedFooterElement.classList.add("selected");
		}
	};

	/*
	 * Changes the current window to newly selected one.
	 *
	 * return void
	 */
	this.changeWindow = function(event) {
		var footerElementName;

		event.stopPropagation();

		footerElementName = event.currentTarget.windowName;

		if (footerElementName != currentWindow)
			window.openWindow(footerElementName);
	};

	/*
	 * Adds scroll event to current container.
	 * Changes the container height to occupy the footer space also (but being covered by it when not hidden)
	 *
	 * return void
	 *
	 * TODO: find a better solution than the setTimeout and than adding the scrollEvent to all containers
	 */
	this.addScrollEventToWindow = function() {
		setTimeout(function() {
			var containers = document.querySelectorAll(".container");

			for (var i=0; i<containers.length; i++)
				containers[i].addEventListener("scroll", this.handleScrollEvent.bind(this));

			containers[0].style.height = "auto";
			containers[0].style.height = (containers[0].clientHeight + footerHeight)+"px";
		}.bind(this), 500);
	};

	/*
	 * Receives the event object and decides wether to hide, unhide or do nothing to the footer
	 *
	 * return void
	 */
	this.handleScrollEvent = function(event) {
		if (currentScrollTop != event.currentTarget.scrollTop) {
			if (currentScrollTop > event.currentTarget.scrollTop) {
				if (isHidden)
					this.unhideFooter();
			}
			else if (!isHidden)
				this.hideFooter();

			currentScrollTop = event.currentTarget.scrollTop;
		}
	};

	/*
	 * Hides the footer by setting his height to 0
	 *
	 * return void
	 */
	this.hideFooter = function() {
		footerDOM.style.height = 0;
		isHidden = true;
	};

	/*
	 * Unhides the footer by setting his height back to footerHeight
	 *
	 * return void
	 */
	this.unhideFooter = function() {
		footerDOM.style.height = footerHeight+"px";
		isHidden = false;
	};

	/*
	 * Register this.selectFooterElement and this.addScrollEventToWindow as a callback for onContainerOpen event
	 */
	eventAggregator.subscribe("onContainerOpen", function() {
		for (var i=0; i<this.functionsToCallOnContainerOpen.length; i++)
			this.functionsToCallOnContainerOpen[i]();
	}.bind(this));
}
