var EventWidget = function(eventObj, callback) {
	var self = this;
	this.e = eventObj;
	this.callback = callback;
	this.notify = function(e) {
		return self.callback(self.e, e);
	};
};


var RenderEngine = function(ZhLogger, metadataFactory, templateManager, $timeout, ZHPromise, restEngine, MetaDataLoader, eventAggregator) {

	this.getWidget = function(widgetName, container) {
		var widget = container.widgets.filter(function(current) {
			return current.name === widgetName;
		})[0];
		if (widget) {
			return widget;
		} else {
			throw new Error("widget not found");
		}
	};
	this.getContainer = function(containerName) {
		return MetaDataLoader.loadContainer(containerName);
	};
	this.bindWidgetDataSource = function(dataSources, container) {
		container.widgets.forEach(buildDataSource);

		function buildDataSource(widget) {
			if (!widget.dataSource && dataSources && dataSources.hasOwnProperty(widget.name)) {
				widget.dataSource = metadataFactory.dataSourceFactory(dataSources[widget.name], widget.getDataSourceFilter(),
					widget);
			}
			if (widget.filter) {
				buildDataSource(widget.filter);
			}
		}
	};

	this.setCurrentRow = function(widget, row) {
		widget.setCurrentRow(row);
	};
	
	this.changeContainer = function(containerName) {
		var event;
		if (templateManager.containers[containerName].beforeinit) {
			event = templateManager.containers[containerName].beforeinit();
		}
		if (!event || !event.isDefaultPrevented()) {
			templateManager.container = templateManager.containers[containerName];

			if (templateManager.wizard && templateManager.wizard.stages[containerName] === void 0) {
				templateManager.historyItems = templateManager.historyItems.filter(function(item) {
					return !templateManager.wizard.stages[item];
				});
				templateManager.wizard = void 0;
			}
			templateManager.container.wizard = templateManager.wizard;

			var firstWidget = templateManager.container.widgets[0];
			templateManager.currentFilter = firstWidget ? firstWidget.filter : void 0;

			this.bindWidgetDataSource(templateManager.data, templateManager.container);
			if (templateManager.containers[containerName].afterinit) {
				templateManager.containers[containerName].afterinit();
			}
			eventAggregator.publish(EventAggregator.ON_CONTAINER_OPEN, { container : templateManager.container });
		}
		return event;
	};

	this.resizeWindowElements = function() {
		var windowHeight, headerHeight, footerHeight, contentHeight;

		windowHeight = $(window).height();
		headerHeight = $("header").height();
		footerHeight = $("footer").height();
		contentHeight = windowHeight - headerHeight - footerHeight;

		$('.tabsHeight').css('width', contentHeight);

		$timeout(function() {
			for (var i in templateManager.scrollers) {
				if (templateManager.scrollers[i] && !isNaN(i)) {
					templateManager.scrollers[i].refresh();
				}
			}
		});

	};
};